@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-package TextFileParser 0.200;
+package TextFileParser 0.201;
 
 # ABSTRACT: an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
@@ -163,12 +163,10 @@ TextFileParser - an extensible Perl class to parse any text file by specifying g
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
-    use strict;
-    use warnings;
     use TextFileParser;
 
     my $parser = new TextFileParser;
@@ -179,8 +177,6 @@ The above code reads a text file and prints the content to C<STDOUT>.
 
 Here's another parser which is derived from C<TextFileParser> as the base class. See how simple it is to make your own parser.
 
-    use strict;
-    use warnings;
     package CSVParser;
     use parent 'TextFileParser';
 
@@ -191,13 +187,21 @@ Here's another parser which is derived from C<TextFileParser> as the base class.
         $self->SUPER::save_record(\@fields);
     }
 
-That's it! Every line will be saved as an array reference containing the elements. Now in C<main::> you can write the following. The C<read> method calls the overridden C<save_record> method from C<CSVParser> package.
+That's it! Every line will be saved as an array reference containing the elements. Now in C<main::> you can write the following.
 
     use CSVParser;
     
     my $a_parser = new CSVParser;
     $a_parser->read(shift @ARGV);
 
+The call to C<read> method calls the C<save_record> method internally. The overridden C<save_record> method from C<CSVParser> package is automatically called.
+
+=head1 DESCRIPTION
+
+This class can be used to parse any arbitrary text file format. C<TextFileParser> does all operations like C<open> file, C<close> file, and line-count. Future versions are expected to include progress-bar support. All these can be re-used in parsing any other text file format. Thus derived classes of C<TextFileParser> will be able to take advantage of these features without having to re-write the code again.
+
+Any drived class of C<TextFileParser> simply needs to override one single method : C<save_record>. In this way, any format of text file can be parsed without having to re-write code that is already included in this class.
+
 =head1 METHODS
 
 =head2 new
@@ -210,7 +214,7 @@ This C<$pars> variable will be used in examples below.
 
 =head2 read
 
-Takes zero or one string argument with the name of the file. Throws an exception if filename provided is either non-existent or cannot be read for any reason.
+Takes zero or one string argument containing the name of the file. Throws an exception if filename provided is either non-existent or cannot be read for any reason.
 
     $pars->read($filename);
 
@@ -224,7 +228,7 @@ B<Recommendation:> Don't override this subroutine. Override C<save_record> inste
 
 =head2 filename
 
-Takes zero or one string argument with the name of a file. Returns the name of the file that was last opened if any. Returns undef if no file has been opened.
+Takes zero or one string argument containing the name of a file. Returns the name of the file that was last opened if any. Returns undef if no file has been opened.
 
     print "Last read ", $pars->filename, "\n";
 
@@ -238,14 +242,10 @@ This is also very useful for error message generation. See example under L<Synop
 
 =head2 save_record
 
-Takes exactly one string argument. This method is automatically called by C<read> method for each line. By default, this method saves the input string as the record.
+Takes exactly one argument which can be anything: C<SCALAR>, or C<ARRAYREF>, or C<HASHREF> or anything else meaningful. This method is automatically called by C<read> method for each line, which in the C<TextFileParser> class is simply saving string records of each line.
 
-This method can be overridden in derived classes. An overriding method definition might call C<SUPER::save_record> passing it a modified record. Records can be anything: C<SCALAR>, C<ARRAYREF>, C<HASHREF>.
+This method can be overridden in derived classes. An overriding method definition might call C<SUPER::save_record> passing it a modified record. Here's an example of a parser that reads multi-line files: if a line starts with a C<'+'> character then it is to be treated as a continuation of the previous line.
 
-Here's an example of a parser that reads multi-line files: if a line starts with a C<'+'> character then it is to be treated as a continuation of the previous line.
-
-    use strict;
-    use warnings;
     package MultilineParser;
     use parent 'TextFileParser';
 
@@ -262,8 +262,7 @@ Here's an example of a parser that reads multi-line files: if a line starts with
 
 Takes no arguments. Returns an array containing all the records that were read by the parser.
 
-    my $i = 0;
-    foreach my $record ($pars->get_records) {
+    foreach my $record ( $pars->get_records ) {
         $i++;
         print "Record: $i: ", $record, "\n";
     }
@@ -276,16 +275,12 @@ Takes no arguments and returns the last saved record. Leaves the saved records u
 
 =head2 pop_record
 
-Takes no arguments and returns the last saved record. In the process the last element from the saved records is lost. To ensure data is not lost, make sure you call C<SUPER::save_record> or simply C<save_record> after a call to C<pop_record>.
+Takes no arguments and pops the last saved record.
 
     my $last_rec = $pars->pop_record;
     $uc_last = uc $last_rec;
     $pars->save_record($uc_last);
 
-=head1 RATIONALE
-
-This text parser is mainly meant for Perl programmers to parse any arbitrary format of text file with modular code. Ideally, the part of the code related to parsing the file line-by-line, storing records, getting records, popping records, and so forth should not be repeated, and should be common to all text files. The only thing that should change is the way the format of the file is processed. This class allows for that separation.
-
 =head1 AUTHOR
 
 Balaji Ramasubramanian <balajiram@cpan.org>
